summaryrefslogtreecommitdiffstats
path: root/kstyles
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:33:40 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:33:40 -0600
commit4fb897b216c41c13f128c71bcc66f60e2dc601c4 (patch)
tree2891b54cd6ec39db133da0110028ec93fc006751 /kstyles
parent8fc8811ef6079a15decd33f1ea5d95dd718e4557 (diff)
downloadtdelibs-4fb897b216c41c13f128c71bcc66f60e2dc601c4.tar.gz
tdelibs-4fb897b216c41c13f128c71bcc66f60e2dc601c4.zip
Rename additional global TQt functions
Diffstat (limited to 'kstyles')
-rw-r--r--kstyles/klegacy/klegacystyle.cpp30
-rw-r--r--kstyles/kthemestyle/kthemebase.cpp28
-rw-r--r--kstyles/kthemestyle/kthemebase.h2
-rw-r--r--kstyles/kthemestyle/kthemestyle.cpp2
-rw-r--r--kstyles/light/lightstyle-v2.cpp2
-rw-r--r--kstyles/light/lightstyle-v3.cpp2
-rw-r--r--kstyles/plastik/plastik.h12
7 files changed, 39 insertions, 39 deletions
diff --git a/kstyles/kthemestyle/kthemebase.cpp b/kstyles/kthemestyle/kthemebase.cpp
index 9da0fdabd..56cbeb09f 100644
--- a/kstyles/kthemestyle/kthemebase.cpp
+++ b/kstyles/kthemestyle/kthemebase.cpp
@@ -336,7 +336,7 @@ void KThemeBase::generateBorderPix( int i )
pbPixmaps[ i ] ->setBorder( KThemePixmap::Right, tmp );
}
else
- qWarning( "KThemeBase: Tried making border from empty pixmap\n" );
+ tqWarning( "KThemeBase: Tried making border from empty pixmap\n" );
}
@@ -660,7 +660,7 @@ TQImage* KThemeBase::loadImage( const TQString &name )
image->load( path );
if ( !image->isNull() )
return ( image );
- qWarning( "KThemeBase: Unable to load image %s\n", name.latin1() );
+ tqWarning( "KThemeBase: Unable to load image %s\n", name.latin1() );
delete image;
return ( NULL );
}
@@ -672,7 +672,7 @@ KThemePixmap* KThemeBase::loadPixmap( const TQString &name )
pixmap->load( path );
if ( !pixmap->isNull() )
return pixmap;
- qWarning( "KThemeBase: Unable to load pixmap %s\n", name.latin1() );
+ tqWarning( "KThemeBase: Unable to load pixmap %s\n", name.latin1() );
delete pixmap;
return ( NULL );
}
@@ -693,7 +693,7 @@ KThemePixmap* KThemeBase::scale( int w, int h, WidgetType widget ) const
cache->insert( pixmaps[ widget ], KThemeCache::FullScale,
widget );
else
- qWarning( "We would have inserted a null pixmap!\n" );
+ tqWarning( "We would have inserted a null pixmap!\n" );
pixmaps[ widget ] = cachePix;
}
else
@@ -718,7 +718,7 @@ KThemePixmap* KThemeBase::scale( int w, int h, WidgetType widget ) const
if ( pixmaps[ widget ] )
cache->insert( pixmaps[ widget ], KThemeCache::HorizontalScale, widget );
else
- qWarning( "We would have inserted a null pixmap!\n" );
+ tqWarning( "We would have inserted a null pixmap!\n" );
pixmaps[ widget ] = cachePix;
}
else
@@ -744,7 +744,7 @@ KThemePixmap* KThemeBase::scale( int w, int h, WidgetType widget ) const
if ( pixmaps[ widget ] )
cache->insert( pixmaps[ widget ], KThemeCache::VerticalScale, widget );
else
- qWarning( "We would have inserted a null pixmap!\n" );
+ tqWarning( "We would have inserted a null pixmap!\n" );
pixmaps[ widget ] = cachePix;
}
else
@@ -902,7 +902,7 @@ KThemePixmap* KThemeBase::scaleBorder( int w, int h, WidgetType widget ) const
pixmap->setMask( mask );
cache->insert( pixmap, KThemeCache::FullScale, widget, true );
if ( !pixmap->mask() )
- qWarning( "No mask for border pixmap!\n" );
+ tqWarning( "No mask for border pixmap!\n" );
}
return ( pixmap );
}
@@ -1127,7 +1127,7 @@ void KThemeBase::applyMiscResourceGroup( TQSettings *config )
else
{
if ( tmpStr != "Opposite" && !tmpStr.isEmpty() )
- qWarning( "KThemeBase: Unrecognized sb button option %s, using Opposite.\n", tmpStr.latin1() );
+ tqWarning( "KThemeBase: Unrecognized sb button option %s, using Opposite.\n", tmpStr.latin1() );
;
prop[ "SButtonPosition" ] = TQString::number( ( int ) SBOpposite );
}
@@ -1139,7 +1139,7 @@ void KThemeBase::applyMiscResourceGroup( TQSettings *config )
else
{
if ( tmpStr != "Normal" && !tmpStr.isEmpty() )
- qWarning( "KThemeBase: Unrecognized arrow option %s, using Normal.\n", tmpStr.latin1() );
+ tqWarning( "KThemeBase: Unrecognized arrow option %s, using Normal.\n", tmpStr.latin1() );
prop[ "ArrowType" ] = TQString::number( ( int ) LargeArrow );
}
tmpStr = config->readEntry( base + "ShadeStyle" );
@@ -1226,7 +1226,7 @@ void KThemeBase::applyResourceGroup( TQSettings *config, int i )
else
{
if ( tmpStr != "Tile" && !tmpStr.isEmpty() )
- qWarning( "KThemeBase: Unrecognized scale option %s, using Tile.\n", tmpStr.latin1() );
+ tqWarning( "KThemeBase: Unrecognized scale option %s, using Tile.\n", tmpStr.latin1() );
tmpVal = ( int ) TileScale;
}
prop[ "ScaleHint" ] = TQString::number( tmpVal );
@@ -1250,7 +1250,7 @@ void KThemeBase::applyResourceGroup( TQSettings *config, int i )
else
{
if ( tmpStr != "None" && !tmpStr.isEmpty() )
- qWarning( "KThemeBase: Unrecognized gradient option %s, using None.\n", tmpStr.latin1() );
+ tqWarning( "KThemeBase: Unrecognized gradient option %s, using None.\n", tmpStr.latin1() );
tmpVal = ( int ) GrNone;
}
prop[ "Gradient" ] = TQString::number( tmpVal );
@@ -1387,7 +1387,7 @@ void KThemeBase::readResourceGroup( int i, TQString *pixnames, TQString *brdname
copyWidgetConfig( sIndex, i, pixnames, brdnames );
}
else
- qWarning( "KThemeBase: Unable to identify source widget for %s\n", widgetEntries[ i ] );
+ tqWarning( "KThemeBase: Unable to identify source widget for %s\n", widgetEntries[ i ] );
return ;
}
// special inheritance for disabled arrows (these are tri-state unlike
@@ -1503,9 +1503,9 @@ void KThemeBase::readResourceGroup( int i, TQString *pixnames, TQString *brdname
pbWidth[ i ] = readNumEntry( prop, "PixmapBWidth", 0 );
if ( pbWidth[ i ] == 0 )
{
- qWarning( "KThemeBase: No border width specified for pixmapped border widget %s\n",
+ tqWarning( "KThemeBase: No border width specified for pixmapped border widget %s\n",
widgetEntries[ i ] );
- qWarning( "KThemeBase: Using default of 2.\n" );
+ tqWarning( "KThemeBase: Using default of 2.\n" );
pbWidth[ i ] = 2;
}
// duplicate check
diff --git a/kstyles/kthemestyle/kthemebase.h b/kstyles/kthemestyle/kthemebase.h
index d07752844..7b60b1016 100644
--- a/kstyles/kthemestyle/kthemebase.h
+++ b/kstyles/kthemestyle/kthemebase.h
@@ -82,7 +82,7 @@ inline void KThemePixmap::setBorder( BorderType type, const TQPixmap &p )
{
if ( b[ type ] )
{
- qWarning( "KThemePixmap: Overwriting existing border!" );
+ tqWarning( "KThemePixmap: Overwriting existing border!" );
delete( b[ type ] );
}
b[ type ] = new TQPixmap( p );
diff --git a/kstyles/kthemestyle/kthemestyle.cpp b/kstyles/kthemestyle/kthemestyle.cpp
index 085ae288e..bd482cffc 100644
--- a/kstyles/kthemestyle/kthemestyle.cpp
+++ b/kstyles/kthemestyle/kthemestyle.cpp
@@ -137,7 +137,7 @@ public:
keys = cfg.readListEntry( "/kthemestyle/themes", &ok);
if ( !ok )
- qWarning( "KThemeStyle cache seems corrupt!\n" ); //Too bad one can't i18n this :-(
+ tqWarning( "KThemeStyle cache seems corrupt!\n" ); //Too bad one can't i18n this :-(
return keys;
}
diff --git a/kstyles/light/lightstyle-v2.cpp b/kstyles/light/lightstyle-v2.cpp
index 2feacba8f..d00233d95 100644
--- a/kstyles/light/lightstyle-v2.cpp
+++ b/kstyles/light/lightstyle-v2.cpp
@@ -51,7 +51,7 @@ public:
if ( ! basestyle )
basestyle = TQStyleFactory::create( TQStyleFactory::keys().first() );
if ( ! basestyle )
- qFatal( "LightStyle: couldn't find a basestyle!" );
+ tqFatal( "LightStyle: couldn't find a basestyle!" );
}
~LightStyleV2Private()
diff --git a/kstyles/light/lightstyle-v3.cpp b/kstyles/light/lightstyle-v3.cpp
index af062f4f9..2e6b24c8d 100644
--- a/kstyles/light/lightstyle-v3.cpp
+++ b/kstyles/light/lightstyle-v3.cpp
@@ -51,7 +51,7 @@ LightStyleV3::LightStyleV3()
if ( ! basestyle )
basestyle = TQStyleFactory::create( TQStyleFactory::keys().first() );
if ( ! basestyle )
- qFatal( "LightStyle: couldn't find a basestyle!" );
+ tqFatal( "LightStyle: couldn't find a basestyle!" );
}
LightStyleV3::~LightStyleV3()
diff --git a/kstyles/plastik/plastik.h b/kstyles/plastik/plastik.h
index fbac34232..3c670d3c0 100644
--- a/kstyles/plastik/plastik.h
+++ b/kstyles/plastik/plastik.h
@@ -339,12 +339,12 @@ private:
(c1Rgb == other.c1Rgb) &&
(horizontal == other.horizontal);
// if(!match) {
-// qDebug("operator ==: CacheEntries don't match!");
-// qDebug("width: %d\t\tother width: %d", width, other.width);
-// qDebug("height: %d\t\tother height: %d", height, other.height);
-// qDebug("fgRgb: %d\t\tother fgRgb: %d", fgRgb, other.fgRgb);
-// qDebug("bgRgb: %d\t\tother bgRgb: %d", bgRgb, other.bgRgb);
-// qDebug("surfaceFlags: %d\t\tother surfaceFlags: %d", surfaceFlags, other.surfaceFlags);
+// tqDebug("operator ==: CacheEntries don't match!");
+// tqDebug("width: %d\t\tother width: %d", width, other.width);
+// tqDebug("height: %d\t\tother height: %d", height, other.height);
+// tqDebug("fgRgb: %d\t\tother fgRgb: %d", fgRgb, other.fgRgb);
+// tqDebug("bgRgb: %d\t\tother bgRgb: %d", bgRgb, other.bgRgb);
+// tqDebug("surfaceFlags: %d\t\tother surfaceFlags: %d", surfaceFlags, other.surfaceFlags);
// }
return match;
}
diff --git a/kstyles/klegacy/klegacystyle.cpp b/kstyles/klegacy/klegacystyle.cpp
index e2cc43dce..3c682bc2b 100644
--- a/kstyles/klegacy/klegacystyle.cpp
+++ b/kstyles/klegacy/klegacystyle.cpp
@@ -869,7 +869,7 @@ GtkObject *GtkObject::find(TQRegExp &r) const {
// this would be nice if tqmoc could parse this file :/
//
// if (o->className() != "GtkObject") {
// qDebug("object is not a GtkObject (className = '%s')",
// o->className());
// continue;
// }
@@ -1101,19 +1101,19 @@ KLegacyStylePrivate::KLegacyStylePrivate()
if (next == "class" || next == "widget" || next == "widget_class") {
if (! parseClass())
- qWarning("\"class\" parse error");
+ tqWarning("\"class\" parse error");
} else if (next == "pixmap_path") {
if (! parsePixmapPath())
- qWarning("\"pixmap_path\" parse error");
+ tqWarning("\"pixmap_path\" parse error");
} else if (next == "style") {
if (! parseStyle())
- qWarning("\"style\" parse error");
+ tqWarning("\"style\" parse error");
}
}
gtkrc.close();
} else
- qWarning("%s: failed to open", gtkrcFilename.latin1());
+ tqWarning("%s: failed to open", gtkrcFilename.latin1());
}
@@ -1152,14 +1152,14 @@ bool KLegacyStylePrivate::parseClass() {
GtkObject *obj = gtktree->find(r);
if (! obj) {
- qWarning("unknown object '%s'", classname.latin1());
+ tqWarning("unknown object '%s'", classname.latin1());
return false;
}
KLegacyStyleData *styledata = styleDict.find(stylename);
if (! styledata) {
- qWarning("no such style '%s' for class '%s' (%p)", stylename.latin1(),
+ tqWarning("no such style '%s' for class '%s' (%p)", stylename.latin1(),
classname.latin1(), styledata);
return false;
}
@@ -1173,7 +1173,7 @@ bool KLegacyStylePrivate::parseClass() {
bool KLegacyStylePrivate::parseImage(KLegacyStyleData *styledata) {
if (filestream.atEnd()) {
- qWarning("parseImage: premature end of stream");
+ tqWarning("parseImage: premature end of stream");
return false;
}
@@ -1187,7 +1187,7 @@ bool KLegacyStylePrivate::parseImage(KLegacyStyleData *styledata) {
}
if (next.isNull() || next != "{") {
- qWarning("parseImage: expected '{' after 'image'\n"
+ tqWarning("parseImage: expected '{' after 'image'\n"
" in style '%s', after processing %d previous images\n",
styledata->name.latin1(), styledata->imageList.count());
return false;
@@ -1257,7 +1257,7 @@ bool KLegacyStylePrivate::parseImage(KLegacyStyleData *styledata) {
if (equals.isNull() || parameter.isNull() || equals != "=" ||
parameter[0] != '\"' || parameter[parameter.length() - 1] != '\"') {
- qWarning("image: file parameter malformed");
+ tqWarning("image: file parameter malformed");
continue;
}
@@ -1356,7 +1356,7 @@ bool KLegacyStylePrivate::parseImage(KLegacyStyleData *styledata) {
if (equals.isNull() || parameter.isNull() || equals != "=" ||
parameter[0] != '\"' || parameter[parameter.length() - 1] != '\"') {
- qWarning("image: overlay_file parameter malformed");
+ tqWarning("image: overlay_file parameter malformed");
continue;
}
@@ -1459,7 +1459,7 @@ bool KLegacyStylePrivate::parseEngine(KLegacyStyleData *styledata) {
if (next == "image") {
if (! parseImage(styledata)) {
- qWarning("image parse error");
+ tqWarning("image parse error");
}
} else if (next == "{") {
paren_count++;
@@ -1553,7 +1553,7 @@ bool KLegacyStylePrivate::parseStyle() {
return true;
} else if (paren != "{") {
- qWarning("parseStyle: expected '{' while parsing style %s",
+ tqWarning("parseStyle: expected '{' while parsing style %s",
stylename.latin1());
return false;
}
@@ -1719,7 +1719,7 @@ bool KLegacyStylePrivate::parseStyle() {
if (next.isNull() || parameter.isNull() || next != "=" ||
parameter[0] != '\"' || parameter[parameter.length() - 1] != '\"') {
- qWarning("font parameter malformed '%s'", parameter.latin1());
+ tqWarning("font parameter malformed '%s'", parameter.latin1());
continue;
}
@@ -1969,7 +1969,7 @@ void KLegacyStyle::polish(TQWidget *widget) {
}
if (widget->inherits(TQPOPUPMENU_OBJECT_NAME_STRING)) {
- qDebug("polishing popup '%s'", widget->className());
+ tqDebug("polishing popup '%s'", widget->className());
metaobject = TQPopupMenu::staticMetaObject();
widget->setBackgroundMode(TQWidget::PaletteBackground);
}
@@ -869,7 +869,7 @@ GtkObject *GtkObject::find(TQRegExp &r) const {
//
// if (o->className() != "GtkObject") {
- // qDebug("object is not a GtkObject (className = '%s')",
+ // tqDebug("object is not a GtkObject (className = '%s')",
// o->className());
// continue;